@@ -31,6 +31,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <limits.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -85,7 +86,7 @@ typedef char CHAR;
 
 /* @DOES_NOT_HAVE_SIGNED@ */
 
-#if defined(__alpha)
+#if (ULONG_MAX > 0xffffffffUL)
 /* 64 bit architectures */
 
 typedef signed char     SBYTE;      /* 1 byte, signed */
