@@ -52,9 +52,12 @@ extern "C" {
 /*========== More type definitions */
 
 /* SLONGLONG: 64bit, signed */
-#if defined(__alpha)
+#if (ULONG_MAX > 0xffffffffUL)
 typedef long		SLONGLONG;
 #define NATIVE_64BIT_INT
+#elif defined(_WIN64)
+typedef __int64		SLONGLONG;
+#define NATIVE_64BIT_INT
 #elif defined(__WATCOMC__)
 typedef __int64		SLONGLONG;
 #elif defined(WIN32) && !defined(__MWERKS__)
