@@ -1,6 +1,6 @@
 /*
     pysol-sound-server
-    Copyright (C) 1999-2002  Markus F.X.J. Oberhumer
+    Copyright (C) 1999-2004  Markus F.X.J. Oberhumer
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 */
 
 
+#include <Python.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -43,11 +44,6 @@
 #include "server.h"
 
 
-#if defined(PYTHON_MODULE)
-
-#include <Python.h>
-
-
 /***********************************************************************
 // dummy SDL video stubs for SMPEG when using `--disable-video'
 ************************************************************************/
@@ -190,10 +186,15 @@ static /* const */ PyMethodDef methods[] =
 //
 ************************************************************************/
 
-#ifdef _WIN32
-_declspec(dllexport)
+#if defined(PyMODINIT_FUNC)
+PyMODINIT_FUNC
+#else
+#if defined(__cplusplus)
+extern "C"
 #endif
-void initpysolsoundserver(void)
+DL_EXPORT(void)
+#endif
+initpysolsoundserver(void)
 {
     PyObject *m, *d, *v;
 
@@ -224,9 +225,6 @@ void initpysolsoundserver(void)
 }
 
 
-#endif /* defined(PYTHON_MODULE) */
-
-
 /*
 vi:ts=4:et
 */
